@@ -267,6 +267,18 @@ def test_bookmarks_11():
     assert re.findall(b'/Title \\((.*)\\)', pdf) == [b'a', b'b']
 
 
+@assert_no_logs
+def test_bookmarks_12():
+    pdf = FakeHTML(string='''
+      <div style="bookmark-level:1; bookmark-label:contents">a</div>
+    ''').write_pdf()
+    # a
+    counts = re.findall(b'/Count ([0-9-]*)', pdf)
+    outlines = counts.pop()
+    assert outlines == b'1'
+    assert re.findall(b'/Title \\((.*)\\)', pdf) == [b'a']
+
+
 @assert_no_logs
 def test_links_none():
     pdf = FakeHTML(string='<body>').write_pdf()
